@@ -17,14 +17,10 @@ from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Job.File import File
 
 __RCSID__ = "$Id$"
 
-#############################################################################
-
 
 class InputFile(File):
-  """InputFile class."""
-  #############################################################################
+    """InputFile class."""
 
-  def writeToXML(self):
-    """creates an xml string."""
-    result = '  <InputFile    Name="' + self.getFileName() + '"/>\n'
-    return result
+    def writeToXML(self):
+        """creates an xml string."""
+        return '  <InputFile    Name="' + self.name + '"/>\n'
