@@ -14,19 +14,17 @@ from __future__ import division
 from __future__ import print_function
 
 from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Replica.Replica import Replica
-from DIRAC import gLogger
 
 __RCSID__ = "$Id$"
 
 
 class FileReplica(Replica):
-  """FileReplica class."""
+    """FileReplica class."""
 
-  def writeToXML(self):
-    """creates an xml string."""
-    gLogger.debug("Job Replica XML writing!!!")
-    result = ''
-    for param in self.getaprams():
-      result += param.writeToXML()
+    def writeToXML(self):
+        """creates an xml string."""
+        result = ""
+        for param in self.params:
+            result += param.writeToXML()
 
-    return result
+        return result
