@@ -21,10 +21,13 @@ from LHCbDIRAC.ProductionManagementSystem.Client.Production import Production
 prod = Production()
 
 
-@pytest.mark.parametrize("input, expected", [
-    (['T1', 'T2'], [{'outputDataType': 't1'}, {'outputDataType': 't2'}]),
-    (['T1', 'HIST'], [{'outputDataType': 't1'}, {'outputDataType': 'hist'}])
-])
+@pytest.mark.parametrize(
+    "input, expected",
+    [
+        (["T1", "T2"], [{"outputDataType": "t1"}, {"outputDataType": "t2"}]),
+        (["T1", "HIST"], [{"outputDataType": "t1"}, {"outputDataType": "hist"}]),
+    ],
+)
 def test__constructOutputFilesList(input, expected):
-  res = prod._constructOutputFilesList(input)
-  assert res == expected
+    res = prod._constructOutputFilesList(input)
+    assert res == expected
